# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/00_core.ipynb.

# %% auto 0
__all__ = ['VIDEO', 'AUDIO', 'IMAGE', 'folders_to_index', 'get_env_var', 'generate_uuid', 'init_path']

# %% ../nbs/00_core.ipynb 3
import base64
import os
import uuid
from pathlib import Path
from typing import Optional

# %% ../nbs/00_core.ipynb 6
def get_env_var(var_name: str, default=None):
    """
    Returns the value of an environment variable if it exists,
    otherwise returns the default value.
    """
    try:
        return os.environ[var_name]
    except KeyError:
        return default

# %% ../nbs/00_core.ipynb 7
def generate_uuid():
    """Generates a uuid 4 string
    Returns:
        an ascii friendly uuid4 string.
    """
    return base64.urlsafe_b64encode(uuid.uuid4().bytes).rstrip(b"=").decode("ascii")

# %% ../nbs/00_core.ipynb 8
def init_path(path: Optional[Path] = None) -> Path:
    """Convert the string to a path object."""
    if path is None:
        return Path.home()
    return Path(path).expanduser().resolve()

# %% ../nbs/00_core.ipynb 9
VIDEO = (
    ".m1v",
    ".mpeg",
    ".mov",
    ".qt",
    ".mpa",
    ".mpg",
    ".mpe",
    ".avi",
    ".movie",
    ".mp4",
)

AUDIO = (".ra", ".aif", ".aiff", ".aifc", ".wav", ".au", ".snd", ".mp3", ".mp2")

IMAGE = (
    ".ras",
    ".xwd",
    ".bmp",
    ".jpe",
    ".jpg",
    ".jpeg",
    ".xpm",
    ".ief",
    ".pbm",
    ".tif",
    ".gif",
    ".ppm",
    ".xbm",
    ".tiff",
    ".rgb",
    ".pgm",
    ".png",
    ".pnm",
)

# %% ../nbs/00_core.ipynb 10
folders_to_index = [
    "Documents",
    "Downloads",
    "Desktop",
    "Music",
    "Videos",
    "Pictures",
    "Movies",
    "OneDrive",
    "Dropbox",
    "Google Drive",
]
